==> root-system_5.34.00.orig.tar.gz: root-system-5.34.00.orig/graf2d/ios/src/IOSPadStub.cxx <==
// @(#)root/graf2d:$Id$
// Author: Timur Pocheptsov, 14/8/2011

/*************************************************************************
 * Copyright (C) 1995-2011, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#include "IOSPadStub.h"

namespace ROOT {
namespace iOS {

//______________________________________________________________________________
TLegend *PadStub::BuildLegend(Double_t, Double_t, Double_t, Double_t, const char *)
{
   return 0;
}

//______________________________________________________________________________
void PadStub::Close(Option_t *)
{
}

//______________________________________________________________________________
void PadStub::AddExec(const char *, const char *)
{
}

//______________________________________________________________________________
void PadStub::CopyPixmap()
{
}

//______________________________________________________________________________
void PadStub::CopyPixmaps()
{
}

//______________________________________________________________________________
void PadStub::DeleteExec(const char *)
{
}

//______________________________________________________________________________
void PadStub::Divide(Int_t, Int_t, Float_t, Float_t, Int_t)
{
}

//______________________________________________________________________________
void PadStub::Draw(Option_t *)
{
}

//______________________________________________________________________________
void PadStub::DrawClassObject(const TObject *, Option_t *)
{
}

//______________________________________________________________________________
void PadStub::SetBatch(Bool_t)
{
}

//______________________________________________________________________________
Int_t PadStub::GetCanvasID() const
{
   return 0;
}

//______________________________________________________________________________
TCanvasImp *PadStub::GetCanvasImp() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetEvent() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetEventX() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetEventY() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetNumber() const
{
   return 0;
}

//______________________________________________________________________________
TVirtualPad *PadStub::GetPad(Int_t) const
{
   return 0;
}

//______________________________________________________________________________
TObject *PadStub::GetPadPointer() const
{
   return 0;
}

//______________________________________________________________________________
TVirtualPad *PadStub::GetPadSave() const
{
   return 0;
}

//______________________________________________________________________________
TVirtualPad *PadStub::GetSelectedPad() const
{
   return 0;
}

//______________________________________________________________________________
TObject *PadStub::GetView3D() const
{
   return 0;
}

//______________________________________________________________________________
void PadStub::ResetView3D(TObject *)
{
}

//______________________________________________________________________________
TCanvas *PadStub::GetCanvas() const
{
   return 0;
}

//______________________________________________________________________________
TVirtualPad *PadStub::GetVirtCanvas() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetPadPaint() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetPixmapID() const
{
   return 0;
}

//______________________________________________________________________________
Bool_t PadStub::HasCrosshair() const
{
   return kFALSE;
}

//______________________________________________________________________________
void PadStub::SetCrosshair(Int_t)
{
}

//______________________________________________________________________________
void PadStub::SetAttFillPS(Color_t, Style_t)
{
}

//______________________________________________________________________________
void PadStub::SetAttLinePS(Color_t, Style_t, Width_t)
{
}

//______________________________________________________________________________
void PadStub::SetAttMarkerPS(Color_t, Style_t, Size_t)
{
}

//______________________________________________________________________________
void PadStub::SetAttTextPS(Int_t, Float_t, Color_t, Style_t, Float_t)
{
}

//______________________________________________________________________________
void PadStub::PaintBorderPS(Double_t, Double_t, Double_t, Double_t, Int_t, Int_t, Int_t, Int_t)
{
}

//______________________________________________________________________________
Int_t PadStub::GetGLDevice()
{
   return 0;
}

//______________________________________________________________________________
void PadStub::SetCopyGLDevice(Bool_t)
{
}

//______________________________________________________________________________
void PadStub::Pop()
{
}

//______________________________________________________________________________
void PadStub::Print(const char *) const
{
}

//______________________________________________________________________________
void PadStub::Print(const char *, Option_t *)
{
}

//______________________________________________________________________________
TVirtualPad *PadStub::GetMother() const
{
   return 0;
}

//______________________________________________________________________________
TObject *PadStub::CreateToolTip(const TBox *, const char *, Long_t)
{
   return 0;
}

//______________________________________________________________________________
void PadStub::DeleteToolTip(TObject *)
{
}

//______________________________________________________________________________
void PadStub::ResetToolTip(TObject *)
{
}

//______________________________________________________________________________
void PadStub::CloseToolTip(TObject *)
{
}

//______________________________________________________________________________
void PadStub::SetToolTipText(const char *, Long_t)
{
}

//______________________________________________________________________________
void PadStub::HighLight(Color_t, Bool_t)
{
}

//______________________________________________________________________________
Color_t PadStub::GetHighLightColor() const
{
   return 0;
}

//______________________________________________________________________________
void PadStub::ls(Option_t *) const
{
}

//______________________________________________________________________________
void PadStub::Modified(Bool_t)
{
}

//______________________________________________________________________________
Bool_t PadStub::OpaqueMoving() const
{
   return kFALSE;
}

//______________________________________________________________________________
Bool_t PadStub::OpaqueResizing() const
{
   return kFALSE;
}

//______________________________________________________________________________
void PadStub::PaintModified()
{
}

//______________________________________________________________________________
void PadStub::RecursiveRemove(TObject *)
{
}

//______________________________________________________________________________
void PadStub::SaveAs(const char *,Option_t *) const
{
}

//______________________________________________________________________________
void PadStub::SetCanvas(TCanvas *)
{
}

//______________________________________________________________________________
void PadStub::SetCanvasSize(UInt_t, UInt_t)
{
}

//______________________________________________________________________________
void PadStub::SetCursor(ECursor)
{
}

//______________________________________________________________________________
void PadStub::SetDoubleBuffer(Int_t)
{
}

//______________________________________________________________________________
void PadStub::SetName(const char *)
{
}

//______________________________________________________________________________
void PadStub::SetTitle(const char *)
{
}

//______________________________________________________________________________
void PadStub::SetSelected(TObject *)
{
}

//______________________________________________________________________________
void PadStub::Update()
{
}

//______________________________________________________________________________
TObject *PadStub::WaitPrimitive(const char *, const char *)
{
   return 0;
}

//______________________________________________________________________________
void PadStub::ReleaseViewer3D(Option_t *)
{
}

//______________________________________________________________________________
Bool_t PadStub::HasViewer3D() const
{
   return kFALSE;
}

}
}

==> root-system_5.34.14.orig.tar.gz: root-system-5.34.14/graf2d/ios/src/IOSPadStub.cxx <==
// @(#)root/graf2d:$Id$
// Author: Timur Pocheptsov, 14/8/2011

/*************************************************************************
 * Copyright (C) 1995-2011, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#include "IOSPadStub.h"

namespace ROOT {
namespace iOS {

//______________________________________________________________________________
TLegend *PadStub::BuildLegend(Double_t, Double_t, Double_t, Double_t, const char *)
{
   return 0;
}

//______________________________________________________________________________
void PadStub::Close(Option_t *)
{
}

//______________________________________________________________________________
void PadStub::AddExec(const char *, const char *)
{
}

//______________________________________________________________________________
void PadStub::CopyPixmap()
{
}

//______________________________________________________________________________
void PadStub::CopyPixmaps()
{
}

//______________________________________________________________________________
void PadStub::DeleteExec(const char *)
{
}

//______________________________________________________________________________
void PadStub::Divide(Int_t, Int_t, Float_t, Float_t, Int_t)
{
}

//______________________________________________________________________________
void PadStub::Draw(Option_t *)
{
}

//______________________________________________________________________________
void PadStub::DrawClassObject(const TObject *, Option_t *)
{
}

//______________________________________________________________________________
void PadStub::SetBatch(Bool_t)
{
}

//______________________________________________________________________________
Int_t PadStub::GetCanvasID() const
{
   return 0;
}

//______________________________________________________________________________
TCanvasImp *PadStub::GetCanvasImp() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetEvent() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetEventX() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetEventY() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetNumber() const
{
   return 0;
}

//______________________________________________________________________________
TVirtualPad *PadStub::GetPad(Int_t) const
{
   return 0;
}

//______________________________________________________________________________
TObject *PadStub::GetPadPointer() const
{
   return 0;
}

//______________________________________________________________________________
TVirtualPad *PadStub::GetPadSave() const
{
   return 0;
}

//______________________________________________________________________________
TVirtualPad *PadStub::GetSelectedPad() const
{
   return 0;
}

//______________________________________________________________________________
TObject *PadStub::GetView3D() const
{
   return 0;
}

//______________________________________________________________________________
void PadStub::ResetView3D(TObject *)
{
}

//______________________________________________________________________________
TCanvas *PadStub::GetCanvas() const
{
   return 0;
}

//______________________________________________________________________________
TVirtualPad *PadStub::GetVirtCanvas() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetPadPaint() const
{
   return 0;
}

//______________________________________________________________________________
Int_t PadStub::GetPixmapID() const
{
   return 0;
}

//______________________________________________________________________________
Bool_t PadStub::HasCrosshair() const
{
   return kFALSE;
}

//______________________________________________________________________________
void PadStub::SetCrosshair(Int_t)
{
}

//______________________________________________________________________________
void PadStub::SetAttFillPS(Color_t, Style_t)
{
}

//______________________________________________________________________________
void PadStub::SetAttLinePS(Color_t, Style_t, Width_t)
{
}

//______________________________________________________________________________
void PadStub::SetAttMarkerPS(Color_t, Style_t, Size_t)
{
}

//______________________________________________________________________________
void PadStub::SetAttTextPS(Int_t, Float_t, Color_t, Style_t, Float_t)
{
}

//______________________________________________________________________________
void PadStub::PaintText(Double_t, Double_t, const wchar_t *)
{
}

//______________________________________________________________________________
void PadStub::PaintTextNDC(Double_t, Double_t, const wchar_t *)
{
}

//______________________________________________________________________________
void PadStub::PaintBorderPS(Double_t, Double_t, Double_t, Double_t, Int_t, Int_t, Int_t, Int_t)
{
}

//______________________________________________________________________________
Int_t PadStub::GetGLDevice()
{
   return 0;
}

//______________________________________________________________________________
void PadStub::SetCopyGLDevice(Bool_t)
{
}

//______________________________________________________________________________
void PadStub::Pop()
{
}

//______________________________________________________________________________
void PadStub::Print(const char *) const
{
}

//______________________________________________________________________________
void PadStub::Print(const char *, Option_t *)
{
}

//______________________________________________________________________________
TVirtualPad *PadStub::GetMother() const
{
   return 0;
}

//______________________________________________________________________________
TObject *PadStub::CreateToolTip(const TBox *, const char *, Long_t)
{
   return 0;
}

//______________________________________________________________________________
void PadStub::DeleteToolTip(TObject *)
{
}

//______________________________________________________________________________
void PadStub::ResetToolTip(TObject *)
{
}

//______________________________________________________________________________
void PadStub::CloseToolTip(TObject *)
{
}

//______________________________________________________________________________
void PadStub::SetToolTipText(const char *, Long_t)
{
}

//______________________________________________________________________________
void PadStub::HighLight(Color_t, Bool_t)
{
}

//______________________________________________________________________________
Color_t PadStub::GetHighLightColor() const
{
   return 0;
}

//______________________________________________________________________________
void PadStub::ls(Option_t *) const
{
}

//______________________________________________________________________________
void PadStub::Modified(Bool_t)
{
}

//______________________________________________________________________________
Bool_t PadStub::OpaqueMoving() const
{
   return kFALSE;
}

//______________________________________________________________________________
Bool_t PadStub::OpaqueResizing() const
{
   return kFALSE;
}

//______________________________________________________________________________
void PadStub::PaintModified()
{
}

//______________________________________________________________________________
void PadStub::RecursiveRemove(TObject *)
{
}

//______________________________________________________________________________
void PadStub::SaveAs(const char *,Option_t *) const
{
}

//______________________________________________________________________________
void PadStub::SetCanvas(TCanvas *)
{
}

//______________________________________________________________________________
void PadStub::SetCanvasSize(UInt_t, UInt_t)
{
}

//______________________________________________________________________________
void PadStub::SetCursor(ECursor)
{
}

//______________________________________________________________________________
void PadStub::SetDoubleBuffer(Int_t)
{
}

//______________________________________________________________________________
void PadStub::SetName(const char *)
{
}

//______________________________________________________________________________
void PadStub::SetTitle(const char *)
{
}

//______________________________________________________________________________
void PadStub::SetSelected(TObject *)
{
}

//______________________________________________________________________________
void PadStub::Update()
{
}

//______________________________________________________________________________
TObject *PadStub::WaitPrimitive(const char *, const char *)
{
   return 0;
}

//______________________________________________________________________________
void PadStub::ReleaseViewer3D(Option_t *)
{
}

//______________________________________________________________________________
Bool_t PadStub::HasViewer3D() const
{
   return kFALSE;
}

}
}
